anewdetguide: Create Determinant Guide (detguide) for pxp Matrix
Description
A determinant guide is a list of 2 levels, each of which contains a list of p!/2
levels, which codes the use of each element of a pxp matrix in the calculation
of the determinant of that matrix. From the guide, the symbolic representation
of the determinant can be produced directly.
Usage
anewdetguide(p,storage,verbose=TRUE)
Arguments
p
Size of matrix (pxp)
storage
Name of directory where detguides are stored.
verbose
Logical. TRUE causes printing of function ID before and after running
Value
"list"
comp1
Products in determinant with +1 coefficient
comp2
Products in determinant with -1 coefficient
Details
Each determinant guide (detguide) is created by cofactor expansion from the detguide of
the next smaller square matrix. If p is set larger than any existing detguide, all
lower detguides larger than the largest existing one are first created in turn.