Learn R Programming

SymbolicDeterminants (version 2.0.0)

confirm.det: Confirm Accuracy of Symbolic Determinant Created by anewdetguide() Function

Description

Compares the determinant calculated by multiplying eigenvalues of a matrix to that calculated by applying the symbolic representation created by this package.

Usage

confirm.det(x=NULL, p, storage, verbose=TRUE)

Arguments

x

a user-defined matrix, or NULL

p

size of matrix (pxp) for which a detguide has been prepared

storage

Quoted name of directory from which to get detguide

verbose

Logical. T causes printing of function ID before and after running

Value

Determinant of x produced obtained by multiplying its eigenvalues and determinant of x obtained by applying the detguide defined by p

Examples

Run this code
# NOT RUN {
confirm.det(x=NULL, p=5,storage=tempdir(),verbose=TRUE)
# }

Run the code above in your browser using DataLab