Description Usage Arguments Details Value Author(s) Examples
Produces a table of existing detguides and parsed detguides for all p or a list of minidetguides and parsed minidetguides for a particular p
1 |
storage |
Quoted name of storage directory |
mini |
Index includes (B)oth detguides and minidetguides, (D)etguides only, (M)inidetguides only |
pmini |
p for minidetguides and related files; ignored if mini='D' |
verbose |
Logical. TRUE causes printing of function ID before and after running |
Provide full path in storage. Example: storage="c:/determinants". If storage directory "name" is in same folder as R Workspace, storage="./name" is sufficient.
Detguides |
Table of existing detguides and existing results of parsing the detguides for each p in the storage directory |
Minidetguides |
Table of existing minidetguides and existing results of parsing the minidetguides for p=pmini |
Call |
Call to this function |
William R. Fairweather
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.