Learn R Programming

SymbolicDeterminants (version 2.0.0)

detindex: Index of Determinant Guides and Symbolic Representation Files

Description

Produces a table of existing detguides and parsed detguides for all p or a list of minidetguides and parsed minidetguides for a particular p

Usage

detindex(storage,  mini=c("B","D","M"), pmini=1, verbose=TRUE)

Arguments

storage

Quoted name of storage directory

mini

Index includes (B)oth detguides and minidetguides, (D)etguides only, (M)inidetguides only

pmini

p for minidetguides and related files; ignored if mini='D'

verbose

Logical. TRUE causes printing of function ID before and after running

Value

Detguides

Table of existing detguides and existing results of parsing the detguides for each p in the storage directory

Minidetguides

Table of existing minidetguides and existing results of parsing the minidetguides for p=pmini

Call

Call to this function

Details

Provide full path in storage. Example: storage="c:/determinants". If storage directory "name" is in same folder as R Workspace, storage="./name" is sufficient.

Examples

Run this code
# NOT RUN {
detindex(storage=tempdir(),mini="B",pmini=5,verbose=TRUE)
# }

Run the code above in your browser using DataLab