powered by
Produces symbolic (textual) representation of determinant of pxp matrix from previously defined determinant guide (detguide) for that matrix
parsedetguide(p, storage, browser="C:/Program Files (x86)/Microsoft/Edge/Application/msedge.exe", symmetric=FALSE, verbose=TRUE)
Size of matrix (pxp)
Name of directory where detguide is stored
Name of program to be used as HTML browser
Logical. T causes printing of determinant for symmetric matrix
Logical. TRUE causes printing of function ID before and after running
Returns symbolic representation to screen and to existing external storage.
# NOT RUN { parsedetguide(p=5, storage=tempdir(), browser="C:/Program Files (x86)/Microsoft/Edge/Application/msedge.exe", symmetric=FALSE,verbose=TRUE) # }
Run the code above in your browser using DataLab